<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../batchprocessing.cpp" line="44"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="45"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>A jelenlegi rendszermag nem támogatja a kiválasztott tömörítési algoritmust, szerkessze a konfigurációs fájlt, és válasszon másik algoritmust.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="170"/>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>MX Snapshot</source>
        <translation>MX pillanatkép</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Optional customization</source>
        <translation>Opcionális testreszabás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Release date:</source>
        <translation>Kiadás dátuma:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Release codename:</source>
        <translation>Kiadás kódneve:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Live kernel:</source>
        <translation>Live kernel:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>Boot options:</source>
        <translation>Indítási paraméterek:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="139"/>
        <source>Release version:</source>
        <translation>Kiadás verziója:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>Change live kernel</source>
        <translation>Live kernel megváltoztatása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Project name:</source>
        <translation>Projekt neve:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A Pillanatkép egy olyan segédprogram, amely indítható lemezképet (ISO) készít a használt rendszeréről, amelyet tárolásra vagy terjesztésre használhat. A folyamat közben kis erőforrás igényű alkalmazásokkal folytathatja a munkát.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Felhasznált hely a / (gyökér) és a /home partíciókon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Location and ISO name</source>
        <translation>Hely és ISO neve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Snapshot location:</source>
        <translation>Pillanatkép helye:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>Select a different snapshot directory</source>
        <translation>Másik pillanatkép könyvtár választása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Snapshot name:</source>
        <translation>Pillanatkép neve:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>Bizonyos könyvtárak kihagyása is lehetséges az alábbi általános lehetőségek bejelölésével, vagy a /etc/mx-snapshot-exclude.list közvetlen szerkesztésére szolgáló gombra kattintva.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>exclude network configurations</source>
        <translation>hálózati beállítások kihagyása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>Networks</source>
        <translation>Hálózatok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>All of the above</source>
        <translation>Az összes fentebbi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>Pictures</source>
        <translation>Képek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>Music</source>
        <translation>Zene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Videos</source>
        <translation>Videók</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Documents</source>
        <translation>Dokumentumok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Type of snapshot:</source>
        <translation>Pillanatkép típusa:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="553"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Felhasználói fiókok megtartása (saját biztonsági mentés)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ez az opció visszaállítja a &amp;quot;demo&amp;quot; és a &amp;quot;root&amp;quot; jelszavakat az MX Linux alapértelmezettre, és nem másolja át a létrehozott személyes fiókokat.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="566"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Felhasználói fiókok alapértelmezettre állítása (másoknak való terjesztés)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Edit Exclusion File</source>
        <translation>Kihagyási lista szerkesztése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="634"/>
        <source>sha512</source>
        <translation>sha512</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Throttle the I/O input rate by the given percentage.</source>
        <translation>Az adatátvitel korlátozása a megadott százalékkal:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>I/O throttle:</source>
        <translation>Adatátvitel korlátozás:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Calculate checksums:</source>
        <translation>Ellenőrzőösszegek számítása:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>ISO compression scheme:</source>
        <translation>ISO tömörítési séma:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Number of CPU cores to use:</source>
        <translation>A felhasználandó processzormagok száma:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="691"/>
        <source>md5</source>
        <translation>md5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="701"/>
        <source>Options:</source>
        <translation>Beállítások:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="848"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>About...</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="858"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="874"/>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="877"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="884"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="964"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="981"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="984"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>fastest, worst compression</source>
        <translation>leggyorsabb, leggyengébb tömörítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>fast, worse compression</source>
        <translation>gyors, gyengébb tömörítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>slow, better compression</source>
        <translation>lassú, erősebb tömörítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>best compromise</source>
        <translation>legjobb kompromisszum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>slowest, best compression</source>
        <translation>leglassabb, legerősebb tömörítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Szabad hely a %1 alatt, ahol a pillanatkép mappa található:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space by removing previous snapshots and saved copies: %1 snapshots are taking up %2 of disk space.</source>
        <translation>Az üres helynek elegendőnek kell lennie a / és a /home adatainak tömörített tárolásához

      Ha szükséges, helyet szabadíthat fel a korábbi pillanatképek és mentett másolatok törlésével: jelenleg %1 pillanatkép %2 helyet foglal el.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Installing </source>
        <translation>Telepítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Please wait.</source>
        <translation>Kérjük várjon.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Kérjük várjon. A használt lemezterület számítása...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <location filename="../mainwindow.cpp" line="354"/>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>A %1 kimeneti fájl már létezik. Adjon meg egy másik fájlnevet, vagy törölje a meglévő fájlt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Snapshot will use the following settings:</source>
        <translation>A pillanatkép a következő beállításokat használja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>- Snapshot directory:</source>
        <translation>- Pillanatkép könyvtár:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>- Kernel to be used:</source>
        <translation>- Használandó kernel:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>A jelenlegi rendszermag nem támogatja a kiválasztott tömörítési algoritmust, szerkessze a konfigurációs fájlt, és válasszon másik algoritmust.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Final chance</source>
        <translation>Utolsó lehetőség</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>A Pillanatkép most már minden szükséges információval rendelkezik ahhoz, hogy ISO fájlt hozzon létre a futó rendszerből.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>A telepített rendszer méretétől és a számítógép kapacitásától függően némi időt vesz igénybe a folyamat végrehajtása.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>OK to start?</source>
        <translation>Indulhat?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Shutdown computer when done.</source>
        <translation>A számítógép leállítása amikor kész.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Could not create working directory. </source>
        <translation>Nem sikerült létrehozni a munkakönyvtárat.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Could not create temporary directory. </source>
        <translation>Nem sikerült létrehozni az ideiglenes könyvtárat.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>Output</source>
        <translation>Kimenet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Edit Boot Menu</source>
        <translation>Rendszerbetöltő menü szerkesztése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>A program most szünetet tart, hogy lehetővé tegye a munkakönyvtárban lévő fájlok szerkesztését. Válassza az Igen lehetőséget a rendszerindító menü szerkesztéséhez, vagy válassza a Nem lehetőséget ennek a lépésnek a kihagyásához, és a pillanatkép létrehozásának folytatásához.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Select kernel</source>
        <translation>Kernel kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>About %1</source>
        <translation>%1 névjegye</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="546"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Program egy Live-CD létrehozására a futó rendszerből az MX Linux rendszerrel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="549"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>%1 License</source>
        <translation>%1 licenc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>%1 Help</source>
        <translation>%1 súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="570"/>
        <source>Select Snapshot Directory</source>
        <translation>Pillanatkép könyvtár kiválasztása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Confirmation</source>
        <translation>Jóváhagyás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Biztos, hogy ki szeretne lépni az alkalmazásból?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../batchprocessing.cpp" line="70"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation>A program megállítja az feldolgozást, és megnyitja az rendszerindítási menüt a szövegszerkesztőben.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation>A futó rendszerről Live-CD készítésére használható eszköz</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Use CLI only</source>
        <translation>Csak parancssor használata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Number of CPU cores to be used.</source>
        <translation>A felhasználandó processzormagok száma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="108"/>
        <source>number</source>
        <translation>szám</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>Output directory</source>
        <translation>Kimeneti könyvtár</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <location filename="../main.cpp" line="109"/>
        <source>path</source>
        <translation>útvonal</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>Output filename</source>
        <translation>Kimeneti fájlnév</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>name</source>
        <translation>név</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation>Megad egy másik rendszermagot, ha nem az alapértelmezetten futót kell használni. Használja az &apos;uname -r&apos; által visszaadott formátumot.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Or the full path: %1</source>
        <translation>Vagy teljes útvonal: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>version, or path</source>
        <translation>verzió vagy útvonal</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Compression level options.</source>
        <translation>Tömörítési szint beállítások.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation>Használjon idézőjelet: &quot;-Xcompression-level &lt;level&gt;&quot;, vagy &quot;-Xalgorithm &lt;algorithm&gt;&quot;, vagy &quot;-Xhc&quot;, nézze meg az mksquashfs man oldalát</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>&quot;option&quot;</source>
        <translation>&quot;opció&quot;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation>Havi pillanatképet hoz létre, a &apos;Hónap&apos; neve belekerül az ISO nevébe, kihagyja az üres hely számítását.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation>Ez az opció alapértékekre állítja a fiókok-visszaállítása és a tömörítés értékét. Az arra vonatkozó argumentumok figyelmen kívül lesznek hagyva.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation>Ne számoljon ellenőrzőösszeget az elkészített ISO fájlhoz</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation>Hagyja ki az üres hely számítását, hogy az ISO el fog-e férni</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="102"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation>Opció az ellenőrzőösszeg számításával kapcsolatos hibák javításához, preempt_rt kerneleken</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Felhasználói fiókok alapértelmezettre állítása (másoknak való terjesztés)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation>Ellenőrzőösszeg számítása az elkészült ISO fájlhoz</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Throttle the I/O input rate by the given percentage. This can be used to reduce the I/O and CPU consumption of Mksquashfs.</source>
        <translation>Az adatátvitel korlátozása a megadott százalékkal. Ez a lemez és a processzor terhelésének csökkentésére használható az Mksquashfs futásakor.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>Work directory</source>
        <translation>Munkakönyvtár</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Exclude main folders, valid choices: </source>
        <translation>Hagyjon ki bizonyos főbb mappákat. Lehetőségek:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="113"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation>Minden kihagyandó elemhez adjon meg újabb ilyen opciót.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="114"/>
        <source>one item</source>
        <translation>egy elem</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="116"/>
        <source>Compression format, valid choices: </source>
        <translation>Tömörítési formátum. Lehetőségek:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>format</source>
        <translation>formátum</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>Shutdown computer when done.</source>
        <translation>A számítógép leállítása amikor kész.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="136"/>
        <location filename="../main.cpp" line="146"/>
        <location filename="../main.cpp" line="187"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Úgy tűnik, hogy root felhasználóként van bejelentkezve. Jelentkezzen ki és jelentkezzen be normál felhasználóként a program használatához.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="159"/>
        <location filename="../main.cpp" line="199"/>
        <source>version:</source>
        <translation>verzió:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="168"/>
        <location filename="../main.cpp" line="194"/>
        <source>You must run this program with sudo or pkexec.</source>
        <translation>Ezt a programot sudo-val vagy pkexec-kel kell futtatnia.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="178"/>
        <source>MX Snapshot</source>
        <translation>MX pillanatkép</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="186"/>
        <location filename="../main.cpp" line="193"/>
        <location filename="../main.cpp" line="252"/>
        <location filename="../settings.cpp" line="250"/>
        <location filename="../settings.cpp" line="265"/>
        <location filename="../settings.cpp" line="735"/>
        <location filename="../settings.cpp" line="834"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <location filename="../main.cpp" line="248"/>
        <location filename="../settings.cpp" line="259"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>A jelenlegi kernel nem támogatja Squashfs fájlrendszert. Nem folytatható.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="86"/>
        <source>Could not create working directory. </source>
        <translation>Nem sikerült létrehozni a munkakönyvtárat.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="111"/>
        <source>Could not create temp directory. </source>
        <translation>Nem sikerült létrehozni az ideiglenes könyvtárat.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="244"/>
        <source>Could not find a usable kernel</source>
        <translation>Nem sikerült egy használható kernel találni</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="368"/>
        <source>Used space on / (root): </source>
        <translation>Foglalt terület a / (gyökér) partíción:</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="371"/>
        <source>estimated</source>
        <translation>becsült</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="384"/>
        <source>Used space on /home: </source>
        <translation>Foglalt terület a /home-on:</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="470"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Szabad hely a %1 alatt, ahol a pillanatkép mappa található:</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="474"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>A szabad helynek elegendőnek kell lennie a / és /home fájlok tömörített adatainak tárolására.

    Szükség esetén szabadíthat fel helyet a korábbi
    pillanatképek és mentett másolatok törlésével:
    %1 pillanatkép %2 lemezterületet foglal el.
</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="492"/>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="493"/>
        <source>Documents</source>
        <translation>Dokumentumok</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="494"/>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="495"/>
        <source>Music</source>
        <translation>Zene</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="496"/>
        <source>Networks</source>
        <translation>Hálózatok</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="497"/>
        <source>Pictures</source>
        <translation>Képek</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="499"/>
        <source>Videos</source>
        <translation>Videók</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="728"/>
        <location filename="../settings.cpp" line="827"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>A %1 kimeneti fájl már létezik. Adjon meg egy másik fájlnevet, vagy törölje a meglévő fájlt.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licenc</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Változások listája</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="80"/>
        <source>Cleaning...</source>
        <translation>Takarítás...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="91"/>
        <location filename="../work.cpp" line="280"/>
        <source>Done</source>
        <translation>Kész</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="102"/>
        <source>Interrupted or failed to complete</source>
        <translation>Megszakítva vagy nem sikerült befejezni</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="135"/>
        <location filename="../work.cpp" line="238"/>
        <location filename="../work.cpp" line="260"/>
        <location filename="../work.cpp" line="298"/>
        <location filename="../work.cpp" line="410"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="136"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation>Nincs elég szabad hely a céllemezen, legalább %1 szükséges</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="139"/>
        <source>You have %1 free space on %2</source>
        <translation>%1 üres terület van ezen: %2</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="142"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation>Ha biztos benne, hogy van elég hely, futtassa újra a programot a -o/--override-size opcióval</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="167"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>Az új ISO fájlrendszer másolása...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="179"/>
        <source>Could not create temp directory. </source>
        <translation>Nem sikerült létrehozni az ideiglenes könyvtárat.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="235"/>
        <source>Squashing filesystem...</source>
        <translation>Fájlrendszer tömörítése...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="239"/>
        <source>Could not create linuxfs file, please check /var/log/%1.log</source>
        <translation>Nem sikerült létrehozni a linuxfs fájlt, ellenőrizze a /var/log/%1.log naplót</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="257"/>
        <source>Creating CD/DVD image file...</source>
        <translation>CD/DVD képfájl létrehozása...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="261"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>Nem sikerült létrehozni az ISO fájlt, ellenőrizze, hogy van-e elég hely a célpartíción.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="267"/>
        <source>Making hybrid iso</source>
        <translation>Hibrid ISO készítése</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="285"/>
        <source>Success</source>
        <translation>Sikeres</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="286"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation>A pillanatkép sikeresen elkészült!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="287"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>A pillanatkép készítése %1 időt vett igénybe.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="288"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>Köszönjük, hogy használta az MX pillanatkép készítőt, futtassa a Live USB készítőt a következőként!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="295"/>
        <source>Installing </source>
        <translation>Telepítés</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="298"/>
        <source>Could not install </source>
        <translation>Telepítés nem sikerült</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="308"/>
        <source>Calculating checksum...</source>
        <translation>Ellenőrzőösszeg számítása...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="347"/>
        <source>Building new initrd...</source>
        <translation>Új initrd össeállítása...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="411"/>
        <source>Could not create working directory. </source>
        <translation>Nem sikerült létrehozni a munkakönyvtárat.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="541"/>
        <source>Calculating total size of excluded files...</source>
        <translation>A kihagyott fájlok méretének kiszámítása...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="551"/>
        <source>Calculating size of root...</source>
        <translation>A gyökérkönyvtár méretének kiszámítása...</translation>
    </message>
</context>
</TS>
